searchData={"content_type":"text/markdown","items":[{"doc":"Interface for making requests to an Onvif compatible device.\n\nCurrently supports WS Discovery probing, a subset of Device wsdl functions\nand a subset of Media wsdl functions.","ref":"Onvif.html","title":"Onvif","type":"module"},{"doc":"A Device is an abstraction of a physical piece of hardware.\n\nSetting up a device is done most easily by passing in the results\nof an Onvif.Discovery.Probe and credentials that can be used to\nperform ONVIF operations on the physical device.","ref":"Onvif.Device.html","title":"Onvif.Device","type":"module"},{"doc":"","ref":"Onvif.Device.html#changeset/2","title":"Onvif.Device.changeset/2","type":"function"},{"doc":"Returns a `{:ok, Device.t()}` tuple with device struct prepopulated with data required to make an Onvif API\nrequest.\n\n  `probe_match` is a valid `Probe.t()` struct for an Onvif compliant device.\n\n  `username` is an Onvif enabled username. Some manufacturers allow the admin credentials\n  to serve this purpose, but generally you need to enable Onvif for a user in the\n  device's web GUI or create dedicated credentials for Onvif.\n\n  `password` is the password for the username above.\n\n  `prefer_https?` will try requests via a probed https address if present. May run into SSL\n  errors so http is generally preferred.\n\n  `prefer_ipv6?` will try requests via a probed ipv6 address if present.\n\n`init` will attempt to make requests for the device's system datetime, an authenticated request\nfor device information, and an authenticated request for services to determine what the device's\nsystem can provide. As this makes several HTTP/HTTPS requests, there are several points of\nfailure which will return as `{:error, reason}`.\n\nIf `init` fails a device can be initialized with `new/3`, providing the address (in form `http://ip:port`),\nthe username and the password. Then override any other field with a struct update because the\ninit helpers haven't filled in any service paths, scopes, or an auth best guess.","ref":"Onvif.Device.html#init/5","title":"Onvif.Device.init/5","type":"function"},{"doc":"Returns a `Device.t()` struct populated with the bare requirements for making a request to an Onvif\nenabled device.\n\n  `address` is a http address with the form `http://ip:port`\n\n  `username` is the onvif enabled username\n\n  `password` is the password for the username\n\nAs this is an override for the init() function, your mileage may vary here, and some manual struct\nupdates may be required for the onvif requests to succeed. It is recommended to check calls on an\nauthentication required endpoint and swap out auth_type for the one that works.","ref":"Onvif.Device.html#new/3","title":"Onvif.Device.new/3","type":"function"},{"doc":"","ref":"Onvif.Device.html#t:t/0","title":"Onvif.Device.t/0","type":"type"},{"doc":"Utility function to encode a `Device.t()` struct into a json string.\n\nIt returns an `{:error, Ecto.Changeset.t()}` if the struct is not valid.","ref":"Onvif.Device.html#to_json/1","title":"Onvif.Device.to_json/1","type":"function"},{"doc":"Returns a `{:ok, Device.t()}` if the map can be properly parsed into a struct\nor `{:error, Ecto.Changeset.t()}` if not.","ref":"Onvif.Device.html#to_struct/1","title":"Onvif.Device.to_struct/1","type":"function"},{"doc":"Module for discovering devices on a local network via WS Discovery protocol","ref":"Onvif.Discovery.html","title":"Onvif.Discovery","type":"module"},{"doc":"Returns a list of `Probe.t()` that have responded via a UDP multicast call\non the local network. Devices on subnets / attached routers won't respond.\n\nDuplicate probes may be returned and it is up to the calling application to\nchoose how to filter out a duplicate.\n\n`opts` are a keyword list of options,\n- `:probe_timeout` denotes how long the probe will wait between new probe responses before closing out the\nlistener. There currently is no forced duration so if the network continuously\ngenerates probe messages this has the possibility to hang.\n- `:multicast_loop` defaults to false. Enabling it will allow host to echoing the multicast packets back to itself.\nThis is useful when this library runs in same device where you simulate a ONVIF device (https://www.happytimesoft.com/products/onvif-server/index.html)\n- `:ip_address` If the local host has many IP addresses, this option specifies which one to use.","ref":"Onvif.Discovery.html#probe/1","title":"Onvif.Discovery.probe/1","type":"function"},{"doc":"Returns a single `Probe.t()` or an error based on filter criteria provided.\n\nDuplicate matches to the criteria will only return the first probe that responded\nto the UDP multicast message. As this uses `probe/0` under the hood it is subject to\nthe same limitations and the default probe timeout.\n\n  `filter` can be a keyword list containing one of:\n\n  `serial` - device serial number, not guaranteed to be present\n\n  `ip_address` - device ip that responded to the onvif multicast\n\n  `mac_address` - device mac address, not guaranteed to be present. Accepts colon separated, dash separated, and only digits\n\n  `name` - device name, usually the model number or something manufacturer determined\n\n  `filter` can also be:\n\n  an onvif scope - `\"onvif://www.onvif.org/scope_name/scope_value\"`, not guaranteed to be present\n\n  a list of onvif scopes - matches the first one to succeed linking to a probe","ref":"Onvif.Discovery.html#probe_by/1","title":"Onvif.Discovery.probe_by/1","type":"function"},{"doc":"A struct representing a discovered device.","ref":"Onvif.Discovery.Probe.html","title":"Onvif.Discovery.Probe","type":"module"},{"doc":"","ref":"Onvif.Discovery.Probe.html#t:t/0","title":"Onvif.Discovery.Probe.t/0","type":"type"},{"doc":"","ref":"Onvif.MacAddress.html","title":"Onvif.MacAddress","type":"module"},{"doc":"","ref":"Onvif.MacAddress.html#mac_just_digits/1","title":"Onvif.MacAddress.mac_just_digits/1","type":"function"},{"doc":"","ref":"Onvif.MacAddress.html#mac_with_colons/1","title":"Onvif.MacAddress.mac_with_colons/1","type":"function"},{"doc":"","ref":"Onvif.Request.html","title":"Onvif.Request","type":"module"},{"doc":"Module describing a float range.","ref":"Onvif.Schemas.FloatRange.html","title":"Onvif.Schemas.FloatRange","type":"module"},{"doc":"","ref":"Onvif.Schemas.FloatRange.html#changeset/2","title":"Onvif.Schemas.FloatRange.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Schemas.FloatRange.html#parse/1","title":"Onvif.Schemas.FloatRange.parse/1","type":"function"},{"doc":"","ref":"Onvif.Schemas.FloatRange.html#t:t/0","title":"Onvif.Schemas.FloatRange.t/0","type":"type"},{"doc":"","ref":"Onvif.Schemas.FloatRange.html#to_xml/1","title":"Onvif.Schemas.FloatRange.to_xml/1","type":"function"},{"doc":"Interface for making requests to the Onvif devices service\n\n  https://www.onvif.org/ver10/device/wsdl/devicemgmt.wsdl","ref":"Onvif.Devices.html","title":"Onvif.Devices","type":"module"},{"doc":"","ref":"Onvif.Devices.html#request/3","title":"Onvif.Devices.request/3","type":"function"},{"doc":"","ref":"Onvif.Devices.GetDeviceInformation.html","title":"Onvif.Devices.GetDeviceInformation","type":"module"},{"doc":"","ref":"Onvif.Devices.GetDeviceInformation.html#request/1","title":"Onvif.Devices.GetDeviceInformation.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetDeviceInformation.html#request_body/0","title":"Onvif.Devices.GetDeviceInformation.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetDeviceInformation.html#response/1","title":"Onvif.Devices.GetDeviceInformation.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetDeviceInformation.html#soap_action/0","title":"Onvif.Devices.GetDeviceInformation.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetHostname.html","title":"Onvif.Devices.GetHostname","type":"module"},{"doc":"","ref":"Onvif.Devices.GetHostname.html#request/1","title":"Onvif.Devices.GetHostname.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetHostname.html#request_body/0","title":"Onvif.Devices.GetHostname.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetHostname.html#response/1","title":"Onvif.Devices.GetHostname.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetHostname.html#soap_action/0","title":"Onvif.Devices.GetHostname.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNTP.html","title":"Onvif.Devices.GetNTP","type":"module"},{"doc":"","ref":"Onvif.Devices.GetNTP.html#request/1","title":"Onvif.Devices.GetNTP.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNTP.html#request_body/0","title":"Onvif.Devices.GetNTP.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNTP.html#response/1","title":"Onvif.Devices.GetNTP.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNTP.html#soap_action/0","title":"Onvif.Devices.GetNTP.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkInterfaces.html","title":"Onvif.Devices.GetNetworkInterfaces","type":"module"},{"doc":"","ref":"Onvif.Devices.GetNetworkInterfaces.html#request/1","title":"Onvif.Devices.GetNetworkInterfaces.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkInterfaces.html#request_body/0","title":"Onvif.Devices.GetNetworkInterfaces.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkInterfaces.html#response/1","title":"Onvif.Devices.GetNetworkInterfaces.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkInterfaces.html#soap_action/0","title":"Onvif.Devices.GetNetworkInterfaces.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkProtocols.html","title":"Onvif.Devices.GetNetworkProtocols","type":"module"},{"doc":"","ref":"Onvif.Devices.GetNetworkProtocols.html#request/1","title":"Onvif.Devices.GetNetworkProtocols.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkProtocols.html#request_body/0","title":"Onvif.Devices.GetNetworkProtocols.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkProtocols.html#response/1","title":"Onvif.Devices.GetNetworkProtocols.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetNetworkProtocols.html#soap_action/0","title":"Onvif.Devices.GetNetworkProtocols.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetScopes.html","title":"Onvif.Devices.GetScopes","type":"module"},{"doc":"","ref":"Onvif.Devices.GetScopes.html#request/1","title":"Onvif.Devices.GetScopes.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetScopes.html#request_body/0","title":"Onvif.Devices.GetScopes.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetScopes.html#response/1","title":"Onvif.Devices.GetScopes.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetScopes.html#soap_action/0","title":"Onvif.Devices.GetScopes.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServiceCapabilities.html","title":"Onvif.Devices.GetServiceCapabilities","type":"module"},{"doc":"","ref":"Onvif.Devices.GetServiceCapabilities.html#request/1","title":"Onvif.Devices.GetServiceCapabilities.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServiceCapabilities.html#request_body/0","title":"Onvif.Devices.GetServiceCapabilities.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServiceCapabilities.html#response/1","title":"Onvif.Devices.GetServiceCapabilities.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServiceCapabilities.html#soap_action/0","title":"Onvif.Devices.GetServiceCapabilities.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServices.html","title":"Onvif.Devices.GetServices","type":"module"},{"doc":"","ref":"Onvif.Devices.GetServices.html#request/1","title":"Onvif.Devices.GetServices.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServices.html#request_body/0","title":"Onvif.Devices.GetServices.request_body/0","type":"function"},{"doc":"Parses the device response into a `{:ok, services}` tuple where `services`\nis a list, discarding the invalid transformations from map into a\nOnvif.Devices.Schemas.Service.t().","ref":"Onvif.Devices.GetServices.html#response/1","title":"Onvif.Devices.GetServices.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetServices.html#soap_action/0","title":"Onvif.Devices.GetServices.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetSystemDateAndTime.html","title":"Onvif.Devices.GetSystemDateAndTime","type":"module"},{"doc":"","ref":"Onvif.Devices.GetSystemDateAndTime.html#request/1","title":"Onvif.Devices.GetSystemDateAndTime.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetSystemDateAndTime.html#request_body/0","title":"Onvif.Devices.GetSystemDateAndTime.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.GetSystemDateAndTime.html#response/1","title":"Onvif.Devices.GetSystemDateAndTime.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.GetSystemDateAndTime.html#soap_action/0","title":"Onvif.Devices.GetSystemDateAndTime.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNTP.html","title":"Onvif.Devices.SetNTP","type":"module"},{"doc":"","ref":"Onvif.Devices.SetNTP.html#request/2","title":"Onvif.Devices.SetNTP.request/2","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNTP.html#request_body/1","title":"Onvif.Devices.SetNTP.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNTP.html#response/1","title":"Onvif.Devices.SetNTP.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNTP.html#soap_action/0","title":"Onvif.Devices.SetNTP.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNetworkProtocols.html","title":"Onvif.Devices.SetNetworkProtocols","type":"module"},{"doc":"","ref":"Onvif.Devices.SetNetworkProtocols.html#request/2","title":"Onvif.Devices.SetNetworkProtocols.request/2","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNetworkProtocols.html#request_body/1","title":"Onvif.Devices.SetNetworkProtocols.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNetworkProtocols.html#response/1","title":"Onvif.Devices.SetNetworkProtocols.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetNetworkProtocols.html#soap_action/0","title":"Onvif.Devices.SetNetworkProtocols.soap_action/0","type":"function"},{"doc":"Module used to set the device system date and time as well as their configuration such as daylight saving and NTP or Manual update type on an ONVIF device.\n  If system time and date are set manually, the request shall include UTCDateTime.\n  A TimeZone token which is not formed according to the rules of IEEE 1003.1 section 8.3 is considered as invalid timezone.\n  The DayLightSavings flag should be set to true to activate any DST settings of the TimeZone string. Clear the DayLightSavings flag if the DST portion of the TimeZone settings should be ignored.\n  The configuration requires a %Onvif.Devices.SystemDateAndTime{} config and a bolean set_time? to manually change the time. It will be ignored if using NTP.\n\n  Ref: https://www.onvif.org/ver10/device/wsdl/devicemgmt.wsdl#op.SetSystemDateAndTime","ref":"Onvif.Devices.SetSystemDateAndTime.html","title":"Onvif.Devices.SetSystemDateAndTime","type":"module"},{"doc":"","ref":"Onvif.Devices.SetSystemDateAndTime.html#request/2","title":"Onvif.Devices.SetSystemDateAndTime.request/2","type":"function"},{"doc":"","ref":"Onvif.Devices.SetSystemDateAndTime.html#request_body/1","title":"Onvif.Devices.SetSystemDateAndTime.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetSystemDateAndTime.html#response/1","title":"Onvif.Devices.SetSystemDateAndTime.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SetSystemDateAndTime.html#soap_action/0","title":"Onvif.Devices.SetSystemDateAndTime.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Devices.SetSystemDateAndTime.html#utc_date_time_element/2","title":"Onvif.Devices.SetSystemDateAndTime.utc_date_time_element/2","type":"function"},{"doc":"","ref":"Onvif.Devices.SystemReboot.html","title":"Onvif.Devices.SystemReboot","type":"module"},{"doc":"","ref":"Onvif.Devices.SystemReboot.html#request/1","title":"Onvif.Devices.SystemReboot.request/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SystemReboot.html#request_body/0","title":"Onvif.Devices.SystemReboot.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Devices.SystemReboot.html#response/1","title":"Onvif.Devices.SystemReboot.response/1","type":"function"},{"doc":"","ref":"Onvif.Devices.SystemReboot.html#soap_action/0","title":"Onvif.Devices.SystemReboot.soap_action/0","type":"function"},{"doc":"DeviceInformation schema","ref":"Onvif.Devices.Schemas.DeviceInformation.html","title":"Onvif.Devices.Schemas.DeviceInformation","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.DeviceInformation.html#changeset/2","title":"Onvif.Devices.Schemas.DeviceInformation.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.DeviceInformation.html#parse/1","title":"Onvif.Devices.Schemas.DeviceInformation.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.DeviceInformation.html#to_json/1","title":"Onvif.Devices.Schemas.DeviceInformation.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.DeviceInformation.html#to_struct/1","title":"Onvif.Devices.Schemas.DeviceInformation.to_struct/1","type":"function"},{"doc":"Schema for the NTP configuration to be used with SetNTP and GetNTP operations.","ref":"Onvif.Devices.Schemas.NTP.html","title":"Onvif.Devices.Schemas.NTP","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#changeset/2","title":"Onvif.Devices.Schemas.NTP.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#ntp_data_changeset/2","title":"Onvif.Devices.Schemas.NTP.ntp_data_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#parse/1","title":"Onvif.Devices.Schemas.NTP.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#parse_ntp_data/1","title":"Onvif.Devices.Schemas.NTP.parse_ntp_data/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#t:t/0","title":"Onvif.Devices.Schemas.NTP.t/0","type":"type"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#to_json/1","title":"Onvif.Devices.Schemas.NTP.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.html#to_struct/1","title":"Onvif.Devices.Schemas.NTP.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.NTPFromDHCP.html","title":"Onvif.Devices.Schemas.NTP.NTPFromDHCP","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NTP.NTPManual.html","title":"Onvif.Devices.Schemas.NTP.NTPManual","type":"module"},{"doc":"Device's network interface","ref":"Onvif.Devices.Schemas.NetworkInterface.html","title":"Onvif.Devices.Schemas.NetworkInterface","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.html#changeset/2","title":"Onvif.Devices.Schemas.NetworkInterface.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.html#parse/1","title":"Onvif.Devices.Schemas.NetworkInterface.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.html#t:t/0","title":"Onvif.Devices.Schemas.NetworkInterface.t/0","type":"type"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.html#to_json/1","title":"Onvif.Devices.Schemas.NetworkInterface.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.html#to_struct/1","title":"Onvif.Devices.Schemas.NetworkInterface.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv4.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv4","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.FromDHCP.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.FromDHCP","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.LinkLocal.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.LinkLocal","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.Manual.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv4.Config.Manual","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.FromDHCP.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.FromDHCP","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.FromRA.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.FromRA","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.LinkLocal.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.LinkLocal","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.Manual.html","title":"Onvif.Devices.Schemas.NetworkInterface.IPv6.Config.Manual","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.Info.html","title":"Onvif.Devices.Schemas.NetworkInterface.Info","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.Link.html","title":"Onvif.Devices.Schemas.NetworkInterface.Link","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.Link.AdminSettings.html","title":"Onvif.Devices.Schemas.NetworkInterface.Link.AdminSettings","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkInterface.Link.OperSettings.html","title":"Onvif.Devices.Schemas.NetworkInterface.Link.OperSettings","type":"module"},{"doc":"A module describing a network protocol.","ref":"Onvif.Devices.Schemas.NetworkProtocol.html","title":"Onvif.Devices.Schemas.NetworkProtocol","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkProtocol.html#changeset/2","title":"Onvif.Devices.Schemas.NetworkProtocol.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkProtocol.html#parse/1","title":"Onvif.Devices.Schemas.NetworkProtocol.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkProtocol.html#t:t/0","title":"Onvif.Devices.Schemas.NetworkProtocol.t/0","type":"type"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkProtocol.html#to_json/1","title":"Onvif.Devices.Schemas.NetworkProtocol.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.NetworkProtocol.html#to_struct/1","title":"Onvif.Devices.Schemas.NetworkProtocol.to_struct/1","type":"function"},{"doc":"Service schema that outlines namespaces and versions","ref":"Onvif.Devices.Schemas.Service.html","title":"Onvif.Devices.Schemas.Service","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.Service.html#changeset/2","title":"Onvif.Devices.Schemas.Service.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.Service.html#parse/1","title":"Onvif.Devices.Schemas.Service.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.Service.html#t:t/0","title":"Onvif.Devices.Schemas.Service.t/0","type":"type"},{"doc":"","ref":"Onvif.Devices.Schemas.Service.html#to_json/1","title":"Onvif.Devices.Schemas.Service.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.Service.html#to_struct/1","title":"Onvif.Devices.Schemas.Service.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.html","title":"Onvif.Devices.Schemas.SystemDateAndTime","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.html#changeset/2","title":"Onvif.Devices.Schemas.SystemDateAndTime.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.html#parse/1","title":"Onvif.Devices.Schemas.SystemDateAndTime.parse/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.html#to_json/1","title":"Onvif.Devices.Schemas.SystemDateAndTime.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.html#to_struct/1","title":"Onvif.Devices.Schemas.SystemDateAndTime.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime.Date.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime.Date","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime.Time.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.LocalDateTime.Time","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.TimeZone.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.TimeZone","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime.Date.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime.Date","type":"module"},{"doc":"","ref":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime.Time.html","title":"Onvif.Devices.Schemas.SystemDateAndTime.UTCDateTime.Time","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.CreateOSD.html","title":"Onvif.Media.Ver10.CreateOSD","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.CreateOSD.html#request/2","title":"Onvif.Media.Ver10.CreateOSD.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.CreateOSD.html#request_body/1","title":"Onvif.Media.Ver10.CreateOSD.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.CreateOSD.html#response/1","title":"Onvif.Media.Ver10.CreateOSD.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.CreateOSD.html#soap_action/0","title":"Onvif.Media.Ver10.CreateOSD.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.DeleteOSD.html","title":"Onvif.Media.Ver10.DeleteOSD","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.DeleteOSD.html#request/2","title":"Onvif.Media.Ver10.DeleteOSD.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.DeleteOSD.html#request_body/1","title":"Onvif.Media.Ver10.DeleteOSD.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.DeleteOSD.html#response/1","title":"Onvif.Media.Ver10.DeleteOSD.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.DeleteOSD.html#soap_action/0","title":"Onvif.Media.Ver10.DeleteOSD.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.html","title":"Onvif.Media.Ver10.GetAudioEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver10.GetAudioEncoderConfiguration.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#request/2","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#request_body/0","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#request_body/1","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#request_body/2","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#response/1","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.html#soap_action/0","title":"Onvif.Media.Ver10.GetAudioEncoderConfigurationOptions.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSD.html","title":"Onvif.Media.Ver10.GetOSD","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSD.html#request/2","title":"Onvif.Media.Ver10.GetOSD.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSD.html#request_body/1","title":"Onvif.Media.Ver10.GetOSD.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSD.html#response/1","title":"Onvif.Media.Ver10.GetOSD.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSD.html#soap_action/0","title":"Onvif.Media.Ver10.GetOSD.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDOptions.html","title":"Onvif.Media.Ver10.GetOSDOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDOptions.html#request/2","title":"Onvif.Media.Ver10.GetOSDOptions.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDOptions.html#request_body/1","title":"Onvif.Media.Ver10.GetOSDOptions.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDOptions.html#response/1","title":"Onvif.Media.Ver10.GetOSDOptions.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDOptions.html#soap_action/0","title":"Onvif.Media.Ver10.GetOSDOptions.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html","title":"Onvif.Media.Ver10.GetOSDs","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#request/1","title":"Onvif.Media.Ver10.GetOSDs.request/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#request/2","title":"Onvif.Media.Ver10.GetOSDs.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#request_body/0","title":"Onvif.Media.Ver10.GetOSDs.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#request_body/1","title":"Onvif.Media.Ver10.GetOSDs.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#response/1","title":"Onvif.Media.Ver10.GetOSDs.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetOSDs.html#soap_action/0","title":"Onvif.Media.Ver10.GetOSDs.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfile.html","title":"Onvif.Media.Ver10.GetProfile","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfile.html#request/2","title":"Onvif.Media.Ver10.GetProfile.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfile.html#request_body/1","title":"Onvif.Media.Ver10.GetProfile.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfile.html#response/1","title":"Onvif.Media.Ver10.GetProfile.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfile.html#soap_action/0","title":"Onvif.Media.Ver10.GetProfile.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfiles.html","title":"Onvif.Media.Ver10.GetProfiles","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfiles.html#request/1","title":"Onvif.Media.Ver10.GetProfiles.request/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfiles.html#request_body/0","title":"Onvif.Media.Ver10.GetProfiles.request_body/0","type":"function"},{"doc":"Parses the device response into a `{:ok, profiles}` tuple where `profiles`\nis a list, discarding the invalid transformations from map into a\nOnvif.Media.Ver10.Schemas.Profile.t().","ref":"Onvif.Media.Ver10.GetProfiles.html#response/1","title":"Onvif.Media.Ver10.GetProfiles.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetProfiles.html#soap_action/0","title":"Onvif.Media.Ver10.GetProfiles.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetServiceCapabilities.html","title":"Onvif.Media.Ver10.GetServiceCapabilities","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetServiceCapabilities.html#request/1","title":"Onvif.Media.Ver10.GetServiceCapabilities.request/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetServiceCapabilities.html#request_body/0","title":"Onvif.Media.Ver10.GetServiceCapabilities.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetServiceCapabilities.html#response/1","title":"Onvif.Media.Ver10.GetServiceCapabilities.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetServiceCapabilities.html#soap_action/0","title":"Onvif.Media.Ver10.GetServiceCapabilities.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetSnapshotUri.html","title":"Onvif.Media.Ver10.GetSnapshotUri","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetSnapshotUri.html#request/2","title":"Onvif.Media.Ver10.GetSnapshotUri.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetSnapshotUri.html#request_body/1","title":"Onvif.Media.Ver10.GetSnapshotUri.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetSnapshotUri.html#response/1","title":"Onvif.Media.Ver10.GetSnapshotUri.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetSnapshotUri.html#soap_action/0","title":"Onvif.Media.Ver10.GetSnapshotUri.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetStreamUri.html","title":"Onvif.Media.Ver10.GetStreamUri","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetStreamUri.html#request/2","title":"Onvif.Media.Ver10.GetStreamUri.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetStreamUri.html#request_body/3","title":"Onvif.Media.Ver10.GetStreamUri.request_body/3","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetStreamUri.html#response/1","title":"Onvif.Media.Ver10.GetStreamUri.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetStreamUri.html#soap_action/0","title":"Onvif.Media.Ver10.GetStreamUri.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.html","title":"Onvif.Media.Ver10.GetVideoEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver10.GetVideoEncoderConfiguration.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#request/2","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#request_body/0","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#request_body/1","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#request_body/2","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#response/1","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.html#soap_action/0","title":"Onvif.Media.Ver10.GetVideoEncoderConfigurationOptions.soap_action/0","type":"function"},{"doc":"Interface for making requests to the 1.0 version of Onvif Media Service\n\nhttps://www.onvif.org/ver10/media/wsdl/media.wsdl","ref":"Onvif.Media.Ver10.Media.html","title":"Onvif.Media.Ver10.Media","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Media.html#request/3","title":"Onvif.Media.Ver10.Media.request/3","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.html","title":"Onvif.Media.Ver10.SetAudioEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver10.SetAudioEncoderConfiguration.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetOSD.html","title":"Onvif.Media.Ver10.SetOSD","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.SetOSD.html#request/2","title":"Onvif.Media.Ver10.SetOSD.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetOSD.html#request_body/1","title":"Onvif.Media.Ver10.SetOSD.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetOSD.html#response/1","title":"Onvif.Media.Ver10.SetOSD.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetOSD.html#soap_action/0","title":"Onvif.Media.Ver10.SetOSD.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.html","title":"Onvif.Media.Ver10.SetVideoEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver10.SetVideoEncoderConfiguration.soap_action/0","type":"function"},{"doc":"OSD (On-Screen Display) specification.","ref":"Onvif.Media.Ver10.Schemas.OSD.html","title":"Onvif.Media.Ver10.Schemas.OSD","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.OSD.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#color_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSD.color_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#image_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSD.image_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_color/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_color/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_image/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_image/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_inner_color/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_inner_color/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_pos/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_pos/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_position/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_position/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#parse_text_string/1","title":"Onvif.Media.Ver10.Schemas.OSD.parse_text_string/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#position_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSD.position_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.OSD.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#text_string_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSD.text_string_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.OSD.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.OSD.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.Image.html","title":"Onvif.Media.Ver10.Schemas.OSD.Image","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.Position.html","title":"Onvif.Media.Ver10.Schemas.OSD.Position","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.TextString.html","title":"Onvif.Media.Ver10.Schemas.OSD.TextString","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.TextString.BackgroundColor.html","title":"Onvif.Media.Ver10.Schemas.OSD.TextString.BackgroundColor","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSD.TextString.FontColor.html","title":"Onvif.Media.Ver10.Schemas.OSD.TextString.FontColor","type":"module"},{"doc":"OSD (On-Screen Display) Options specification.","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#color_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.color_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#color_space_range_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.color_space_range_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#image_option_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.image_option_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#int_range_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.int_range_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#maximum_number_of_osds_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.maximum_number_of_osds_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_color/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_color/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_color_space_range/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_color_space_range/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_image_option/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_image_option/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_int_range/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_int_range/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_maximum_number_of_osds/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_maximum_number_of_osds/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_text_color/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_text_color/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#parse_text_option/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.parse_text_option/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.OSDOptions.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#text_color_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.text_color_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#text_option_changeset/2","title":"Onvif.Media.Ver10.Schemas.OSDOptions.text_option_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.OSDOptions.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.ImageOption.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.ImageOption","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.MaximumNumberOfOSDs.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.MaximumNumberOfOSDs","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.X.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.X","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.Y.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.Y","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.Z.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Color.ColorSpaceRange.Z","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Transparent.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.BackgroundColor.Transparent","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.X.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.X","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.Y.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.Y","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.Z.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Color.ColorSpaceRange.Z","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Transparent.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontColor.Transparent","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontSizeRange.html","title":"Onvif.Media.Ver10.Schemas.OSDOptions.TextOption.FontSizeRange","type":"module"},{"doc":"A media profile, or a standard definition of media configurations for video","ref":"Onvif.Media.Ver10.Schemas.Profile.html","title":"Onvif.Media.Ver10.Schemas.Profile","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.to_struct/1","type":"function"},{"doc":"Indication which AnalyticsModules shall output metadata. Note that the streaming behavior is undefined if the list includes items that are not part of the associated AnalyticsConfiguration.","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.AnalyticsModule.html","title":"Onvif.Media.Ver10.Schemas.Profile.AnalyticsEngineConfiguration.AnalyticsModule","type":"module"},{"doc":"Optional configuration of the Audio encoder.","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfiguration.to_struct/1","type":"function"},{"doc":"Optional configuration of the Audio encoder.","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#options_changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.options_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#parse_options/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.parse_options/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#parse_unbound_int_list/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.parse_unbound_int_list/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.html#unbound_int_list_changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.unbound_int_list_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options.BitrateList.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options.BitrateList","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options.SampleRateList.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioEncoderConfigurationOption.Options.SampleRateList","type":"module"},{"doc":"AudioSourceConfiguration schema for Media Ver10","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.AudioSourceConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Extension.html","title":"Onvif.Media.Ver10.Schemas.Profile.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Extension.AudioDecoderConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.Extension.AudioDecoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Extension.AudioOutputConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.Extension.AudioOutputConfiguration","type":"module"},{"doc":"Optional configuration of the metadata stream.","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.PtzStatus.html","title":"Onvif.Media.Ver10.Schemas.Profile.MetadataConfiguration.PtzStatus","type":"module"},{"doc":"MulticastConfiguration for Media Ver10","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.IpAddress.html","title":"Onvif.Media.Ver10.Schemas.Profile.MulticastConfiguration.IpAddress","type":"module"},{"doc":"Parameters schema for Media Ver10","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.html","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.ElementItem.html","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters.ElementItem","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.Parameters.SimpleItem.html","title":"Onvif.Media.Ver10.Schemas.Profile.Parameters.SimpleItem","type":"module"},{"doc":"Optional configuration of the pan tilt zoom unit.","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.DefaultPtzSpeed.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.DefaultPtzSpeed","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection.EFlip.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection.EFlip","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection.Reverse.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.Extension.PtControlDirection.Reverse","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range.XRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range.XRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range.YRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.PanTiltLimits.Range.YRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits.Range.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits.Range","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits.Range.XRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.PtzConfiguration.ZoomLimits.Range.XRange","type":"module"},{"doc":"This element contains a list of Analytics configurations.","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration.Rule.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoAnalyticsConfiguration.RuleEngineConfiguration.Rule","type":"module"},{"doc":"Configurations for the video encoding","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.H264Configuration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.H264Configuration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.Mpeg4Configuration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.Mpeg4Configuration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.RateControl.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.RateControl","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.Resolution.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfiguration.Resolution","type":"module"},{"doc":"Optional configuration of the Video encoder.","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html#to_json/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.BitrateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.BitrateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.GovLengthRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.GovLengthRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.ResolutionsAvailable1.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.H264Options.ResolutionsAvailable1","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.BitrateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.BitrateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.ResolutionsAvailable.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.JpegOptions.ResolutionsAvailable","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.BitrateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.BitrateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.GovLengthRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.GovLengthRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.ResolutionsAvailable.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Extension.Mpeg4Options.ResolutionsAvailable","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.GovLengthRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.GovLengthRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.ResolutionsAvailable.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.H264Options.ResolutionsAvailable","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.ResolutionsAvailable.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.JpegOptions.ResolutionsAvailable","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.EncodingIntervalRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.EncodingIntervalRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.FrameRateRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.FrameRateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.GovLengthRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.GovLengthRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.ResolutionsAvailable.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.Mpeg4Options.ResolutionsAvailable","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.QualityRange.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoEncoderConfigurationOption.QualityRange","type":"module"},{"doc":"Optional configuration of the Video input.","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.html#changeset/2","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.html#parse/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.html#t:t/0","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.html#to_struct/1","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Bounds.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Bounds","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.LensOffset.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.LensOffset","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.Projection.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.LensDescription.Projection","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.SceneOrientation.html","title":"Onvif.Media.Ver10.Schemas.Profile.VideoSourceConfiguration.Extension.Rotate.Extension.SceneOrientation","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.ServiceCapabilities.ProfileCapabilities.html","title":"Onvif.Media.Ver10.Schemas.ServiceCapabilities.ProfileCapabilities","type":"module"},{"doc":"","ref":"Onvif.Media.Ver10.Schemas.ServiceCapabilities.StreamingCapabilities.html","title":"Onvif.Media.Ver10.Schemas.ServiceCapabilities.StreamingCapabilities","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#request/2","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#request_body/0","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#request_body/1","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#request_body/2","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#response/1","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.html#soap_action/0","title":"Onvif.Media.Ver20.GetAudioEncoderConfigurations.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetProfiles.html","title":"Onvif.Media.Ver20.GetProfiles","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetProfiles.html#request/2","title":"Onvif.Media.Ver20.GetProfiles.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetProfiles.html#request_body/0","title":"Onvif.Media.Ver20.GetProfiles.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetProfiles.html#request_body/1","title":"Onvif.Media.Ver20.GetProfiles.request_body/1","type":"function"},{"doc":"Parses the device response into a `{:ok, profiles}` tuple where `profiles`\nis a list, discarding the invalid transformations from map into a\nOnvif.Media.Ver20.Schemas.Profile.t().","ref":"Onvif.Media.Ver20.GetProfiles.html#response/1","title":"Onvif.Media.Ver20.GetProfiles.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetProfiles.html#soap_action/0","title":"Onvif.Media.Ver20.GetProfiles.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetStreamUri.html","title":"Onvif.Media.Ver20.GetStreamUri","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetStreamUri.html#request/2","title":"Onvif.Media.Ver20.GetStreamUri.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetStreamUri.html#request_body/2","title":"Onvif.Media.Ver20.GetStreamUri.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetStreamUri.html#response/1","title":"Onvif.Media.Ver20.GetStreamUri.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetStreamUri.html#soap_action/0","title":"Onvif.Media.Ver20.GetStreamUri.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.html","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.html#request/2","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.html#request_body/2","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.html#response/1","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.html#soap_action/0","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurationOptions.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.html","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurations","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.html#request/2","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.html#request_body/2","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.html#response/1","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.html#soap_action/0","title":"Onvif.Media.Ver20.GetVideoEncoderConfigurations.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoSourceConfigurations.html","title":"Onvif.Media.Ver20.GetVideoSourceConfigurations","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoSourceConfigurations.html#request/2","title":"Onvif.Media.Ver20.GetVideoSourceConfigurations.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoSourceConfigurations.html#request_body/2","title":"Onvif.Media.Ver20.GetVideoSourceConfigurations.request_body/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoSourceConfigurations.html#response/1","title":"Onvif.Media.Ver20.GetVideoSourceConfigurations.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.GetVideoSourceConfigurations.html#soap_action/0","title":"Onvif.Media.Ver20.GetVideoSourceConfigurations.soap_action/0","type":"function"},{"doc":"Interface for making requests to the 2.0 version of Onvif Media Service\n\nhttps://www.onvif.org/ver20/media/wsdl/media.wsdl","ref":"Onvif.Media.Ver20.Media.html","title":"Onvif.Media.Ver20.Media","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Media.html#request/3","title":"Onvif.Media.Ver20.Media.request/3","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.html","title":"Onvif.Media.Ver20.SetAudioEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver20.SetAudioEncoderConfiguration.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.html","title":"Onvif.Media.Ver20.SetVideoEncoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.html#request/2","title":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.request/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.html#request_body/1","title":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.html#response/1","title":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.response/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.html#soap_action/0","title":"Onvif.Media.Ver20.SetVideoEncoderConfiguration.soap_action/0","type":"function"},{"doc":"A media profile","ref":"Onvif.Media.Ver20.Schemas.Profile.html","title":"Onvif.Media.Ver20.Schemas.Profile","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.html#changeset/2","title":"Onvif.Media.Ver20.Schemas.Profile.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.html#parse/1","title":"Onvif.Media.Ver20.Schemas.Profile.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.html#t:t/0","title":"Onvif.Media.Ver20.Schemas.Profile.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.html#to_json/1","title":"Onvif.Media.Ver20.Schemas.Profile.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.html#to_struct/1","title":"Onvif.Media.Ver20.Schemas.Profile.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.Extension.html","title":"Onvif.Media.Ver20.Schemas.Profile.Extension","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.Extension.AudioDecoderConfiguration.html","title":"Onvif.Media.Ver20.Schemas.Profile.Extension.AudioDecoderConfiguration","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.Extension.AudioOutputConfiguration.html","title":"Onvif.Media.Ver20.Schemas.Profile.Extension.AudioOutputConfiguration","type":"module"},{"doc":"VideoEncoder schema for Media Ver20","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html#changeset/2","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html#parse/1","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html#t:t/0","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html#to_json/1","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.html#to_struct/1","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.RateControl.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.RateControl","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.Resolution.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoder.Resolution","type":"module"},{"doc":"Available options for video encoder configuration","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.html#changeset/2","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.html#parse/1","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.parse/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.html#t:t/0","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.t/0","type":"type"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.html#to_struct/1","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.BitrateRange.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.BitrateRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.QualityRange.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.QualityRange","type":"module"},{"doc":"","ref":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.ResolutionsAvailable.html","title":"Onvif.Media.Ver20.Schemas.Profile.VideoEncoderConfigurationOption.ResolutionsAvailable","type":"module"},{"doc":"Interface for making requests to the Onvif recording service\n  http://www.onvif.org/onvif/ver10/recording.wsdl","ref":"Onvif.Recording.html","title":"Onvif.Recording","type":"module"},{"doc":"","ref":"Onvif.Recording.html#request/2","title":"Onvif.Recording.request/2","type":"function"},{"doc":"","ref":"Onvif.Recording.html#request/3","title":"Onvif.Recording.request/3","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html","title":"Onvif.Recording.CreateRecording","type":"module"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_address/1","title":"Onvif.Recording.CreateRecording.gen_address/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_content/1","title":"Onvif.Recording.CreateRecording.gen_content/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_description/1","title":"Onvif.Recording.CreateRecording.gen_description/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_location/1","title":"Onvif.Recording.CreateRecording.gen_location/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_maximum_retention_time/1","title":"Onvif.Recording.CreateRecording.gen_maximum_retention_time/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_name/1","title":"Onvif.Recording.CreateRecording.gen_name/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#gen_source_id/1","title":"Onvif.Recording.CreateRecording.gen_source_id/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#request/2","title":"Onvif.Recording.CreateRecording.request/2","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#request_body/1","title":"Onvif.Recording.CreateRecording.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#response/1","title":"Onvif.Recording.CreateRecording.response/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecording.html#soap_action/0","title":"Onvif.Recording.CreateRecording.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecordingJob.html","title":"Onvif.Recording.CreateRecordingJob","type":"module"},{"doc":"","ref":"Onvif.Recording.CreateRecordingJob.html#request/2","title":"Onvif.Recording.CreateRecordingJob.request/2","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecordingJob.html#request_body/3","title":"Onvif.Recording.CreateRecordingJob.request_body/3","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecordingJob.html#response/1","title":"Onvif.Recording.CreateRecordingJob.response/1","type":"function"},{"doc":"","ref":"Onvif.Recording.CreateRecordingJob.html#soap_action/0","title":"Onvif.Recording.CreateRecordingJob.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordingJobs.html","title":"Onvif.Recording.GetRecordingJobs","type":"module"},{"doc":"","ref":"Onvif.Recording.GetRecordingJobs.html#request/1","title":"Onvif.Recording.GetRecordingJobs.request/1","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordingJobs.html#request_body/0","title":"Onvif.Recording.GetRecordingJobs.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordingJobs.html#response/1","title":"Onvif.Recording.GetRecordingJobs.response/1","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordingJobs.html#soap_action/0","title":"Onvif.Recording.GetRecordingJobs.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordings.html","title":"Onvif.Recording.GetRecordings","type":"module"},{"doc":"","ref":"Onvif.Recording.GetRecordings.html#request/1","title":"Onvif.Recording.GetRecordings.request/1","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordings.html#request_body/0","title":"Onvif.Recording.GetRecordings.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordings.html#response/1","title":"Onvif.Recording.GetRecordings.response/1","type":"function"},{"doc":"","ref":"Onvif.Recording.GetRecordings.html#soap_action/0","title":"Onvif.Recording.GetRecordings.soap_action/0","type":"function"},{"doc":"Onvif.Recording.Recordings schema.","ref":"Onvif.Recording.Schemas.Recording.html","title":"Onvif.Recording.Schemas.Recording","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#changeset/2","title":"Onvif.Recording.Schemas.Recording.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#configuration_changeset/2","title":"Onvif.Recording.Schemas.Recording.configuration_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse/1","title":"Onvif.Recording.Schemas.Recording.parse/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse_configuration/1","title":"Onvif.Recording.Schemas.Recording.parse_configuration/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse_source/1","title":"Onvif.Recording.Schemas.Recording.parse_source/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse_track/1","title":"Onvif.Recording.Schemas.Recording.parse_track/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse_track_configuration/1","title":"Onvif.Recording.Schemas.Recording.parse_track_configuration/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#parse_tracks/1","title":"Onvif.Recording.Schemas.Recording.parse_tracks/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#source_changeset/2","title":"Onvif.Recording.Schemas.Recording.source_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#t:t/0","title":"Onvif.Recording.Schemas.Recording.t/0","type":"type"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#to_json/1","title":"Onvif.Recording.Schemas.Recording.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#to_struct/1","title":"Onvif.Recording.Schemas.Recording.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#track_changeset/2","title":"Onvif.Recording.Schemas.Recording.track_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#track_configuration_changeset/2","title":"Onvif.Recording.Schemas.Recording.track_configuration_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.html#tracks_changeset/2","title":"Onvif.Recording.Schemas.Recording.tracks_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.Configuration.html","title":"Onvif.Recording.Schemas.Recording.Configuration","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.Configuration.Source.html","title":"Onvif.Recording.Schemas.Recording.Configuration.Source","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.Tracks.html","title":"Onvif.Recording.Schemas.Recording.Tracks","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.Tracks.Track.html","title":"Onvif.Recording.Schemas.Recording.Tracks.Track","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.Recording.Tracks.Track.Configuration.html","title":"Onvif.Recording.Schemas.Recording.Tracks.Track.Configuration","type":"module"},{"doc":"Recordings.","ref":"Onvif.Recording.Schemas.RecordingJob.html","title":"Onvif.Recording.Schemas.RecordingJob","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#changeset/2","title":"Onvif.Recording.Schemas.RecordingJob.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#job_configuration_changeset/2","title":"Onvif.Recording.Schemas.RecordingJob.job_configuration_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#parse/1","title":"Onvif.Recording.Schemas.RecordingJob.parse/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#parse_job_configuration/1","title":"Onvif.Recording.Schemas.RecordingJob.parse_job_configuration/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#parse_source/1","title":"Onvif.Recording.Schemas.RecordingJob.parse_source/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#parse_source_token/1","title":"Onvif.Recording.Schemas.RecordingJob.parse_source_token/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#parse_track/1","title":"Onvif.Recording.Schemas.RecordingJob.parse_track/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#source_changeset/2","title":"Onvif.Recording.Schemas.RecordingJob.source_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#source_token_changeset/2","title":"Onvif.Recording.Schemas.RecordingJob.source_token_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#t:t/0","title":"Onvif.Recording.Schemas.RecordingJob.t/0","type":"type"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#to_json/1","title":"Onvif.Recording.Schemas.RecordingJob.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#to_struct/1","title":"Onvif.Recording.Schemas.RecordingJob.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.html#track_changeset/2","title":"Onvif.Recording.Schemas.RecordingJob.track_changeset/2","type":"function"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.html","title":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source.html","title":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source.SourceToken.html","title":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source.SourceToken","type":"module"},{"doc":"","ref":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source.Tracks.html","title":"Onvif.Recording.Schemas.RecordingJob.JobConfiguration.Source.Tracks","type":"module"},{"doc":"Interface for making requests to the Onvif replay service\n  https://www.onvif.org/ver10/replay.wsdl","ref":"Onvif.Replay.html","title":"Onvif.Replay","type":"module"},{"doc":"","ref":"Onvif.Replay.html#request/2","title":"Onvif.Replay.request/2","type":"function"},{"doc":"","ref":"Onvif.Replay.html#request/3","title":"Onvif.Replay.request/3","type":"function"},{"doc":"","ref":"Onvif.Replay.GetReplayUri.html","title":"Onvif.Replay.GetReplayUri","type":"module"},{"doc":"","ref":"Onvif.Replay.GetReplayUri.html#request/2","title":"Onvif.Replay.GetReplayUri.request/2","type":"function"},{"doc":"","ref":"Onvif.Replay.GetReplayUri.html#request_body/3","title":"Onvif.Replay.GetReplayUri.request_body/3","type":"function"},{"doc":"","ref":"Onvif.Replay.GetReplayUri.html#response/1","title":"Onvif.Replay.GetReplayUri.response/1","type":"function"},{"doc":"","ref":"Onvif.Replay.GetReplayUri.html#soap_action/0","title":"Onvif.Replay.GetReplayUri.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Replay.GetServiceCapabilities.html","title":"Onvif.Replay.GetServiceCapabilities","type":"module"},{"doc":"","ref":"Onvif.Replay.GetServiceCapabilities.html#request/1","title":"Onvif.Replay.GetServiceCapabilities.request/1","type":"function"},{"doc":"","ref":"Onvif.Replay.GetServiceCapabilities.html#request_body/0","title":"Onvif.Replay.GetServiceCapabilities.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Replay.GetServiceCapabilities.html#response/1","title":"Onvif.Replay.GetServiceCapabilities.response/1","type":"function"},{"doc":"","ref":"Onvif.Replay.GetServiceCapabilities.html#soap_action/0","title":"Onvif.Replay.GetServiceCapabilities.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Replay.ServiceCapabilities.html","title":"Onvif.Replay.ServiceCapabilities","type":"module"},{"doc":"Converts a parsed map into a %Onvif.Replay.ServiceCapabilities{} struct with validated types.","ref":"Onvif.Replay.ServiceCapabilities.html#from_parsed/1","title":"Onvif.Replay.ServiceCapabilities.from_parsed/1","type":"function"},{"doc":"","ref":"Onvif.Replay.ServiceCapabilities.html#t:t/0","title":"Onvif.Replay.ServiceCapabilities.t/0","type":"type"},{"doc":"Interface for making requests to the Onvif search service\n  https://www.onvif.org/ver10/search.wsdl","ref":"Onvif.Search.html","title":"Onvif.Search","type":"module"},{"doc":"","ref":"Onvif.Search.html#request/2","title":"Onvif.Search.request/2","type":"function"},{"doc":"","ref":"Onvif.Search.html#request/3","title":"Onvif.Search.request/3","type":"function"},{"doc":"","ref":"Onvif.Search.FindEvents.html","title":"Onvif.Search.FindEvents","type":"module"},{"doc":"","ref":"Onvif.Search.FindEvents.html#request/2","title":"Onvif.Search.FindEvents.request/2","type":"function"},{"doc":"","ref":"Onvif.Search.FindEvents.html#request_body/1","title":"Onvif.Search.FindEvents.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Search.FindEvents.html#response/1","title":"Onvif.Search.FindEvents.response/1","type":"function"},{"doc":"","ref":"Onvif.Search.FindEvents.html#soap_action/0","title":"Onvif.Search.FindEvents.soap_action/0","type":"function"},{"doc":"FindRecordings starts a search session, looking for recordings that matches the scope defined in the request.\nResults from the search are acquired using the `Onvif.Search.GetRecordingSearchResults/2` request,\nspecifying the search token returned from this request.\n\nThe device shall continue searching until one of the following occurs:\n  * The entire time range from StartPoint to EndPoint has been searched through.\n  * The total number of matches has been found, defined by the MaxMatches parameter.\n  * The session has been ended by a client EndSession request.\n  * The session has been ended because KeepAliveTime since the last request related to this session has expired.\n\nThe order of the results is undefined, to allow the device to return results in any order they are found.","ref":"Onvif.Search.FindRecordings.html","title":"Onvif.Search.FindRecordings","type":"module"},{"doc":"","ref":"Onvif.Search.FindRecordings.html#request/2","title":"Onvif.Search.FindRecordings.request/2","type":"function"},{"doc":"","ref":"Onvif.Search.FindRecordings.html#request_body/1","title":"Onvif.Search.FindRecordings.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Search.FindRecordings.html#response/1","title":"Onvif.Search.FindRecordings.response/1","type":"function"},{"doc":"","ref":"Onvif.Search.FindRecordings.html#soap_action/0","title":"Onvif.Search.FindRecordings.soap_action/0","type":"function"},{"doc":"GetRecordingSearchResults acquires the results from a recording search session previously initiated\nby a `Onvif.Search.FindRecordings.request/2` operation. The response shall not include results already\nreturned in previous requests for the same session.\n\nIf MaxResults is specified, the response shall not contain more than MaxResults results.\nThe number of results relates to the number of recordings. For viewing individual recorded data\nfor a signal track use the FindEvents method.\n\nGetRecordingSearchResults shall block until:\n  * MaxResults results are available for the response if MaxResults is specified.\n  * MinResults results are available for the response if MinResults is specified.\n  * WaitTime has expired.\n  * Search is completed or stopped.","ref":"Onvif.Search.GetRecordingSearchResults.html","title":"Onvif.Search.GetRecordingSearchResults","type":"module"},{"doc":"","ref":"Onvif.Search.GetRecordingSearchResults.html#request/2","title":"Onvif.Search.GetRecordingSearchResults.request/2","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSearchResults.html#request_body/1","title":"Onvif.Search.GetRecordingSearchResults.request_body/1","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSearchResults.html#response/1","title":"Onvif.Search.GetRecordingSearchResults.response/1","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSearchResults.html#soap_action/0","title":"Onvif.Search.GetRecordingSearchResults.soap_action/0","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSummary.html","title":"Onvif.Search.GetRecordingSummary","type":"module"},{"doc":"","ref":"Onvif.Search.GetRecordingSummary.html#request/1","title":"Onvif.Search.GetRecordingSummary.request/1","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSummary.html#request_body/0","title":"Onvif.Search.GetRecordingSummary.request_body/0","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSummary.html#response/1","title":"Onvif.Search.GetRecordingSummary.response/1","type":"function"},{"doc":"","ref":"Onvif.Search.GetRecordingSummary.html#soap_action/0","title":"Onvif.Search.GetRecordingSummary.soap_action/0","type":"function"},{"doc":"A module describing results from `Onvif.Search.GetRecordingSearchResults.request/2`.","ref":"Onvif.Search.Schemas.FindRecordingResult.html","title":"Onvif.Search.Schemas.FindRecordingResult","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordingResult.html#parse/1","title":"Onvif.Search.Schemas.FindRecordingResult.parse/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordingResult.html#t:t/0","title":"Onvif.Search.Schemas.FindRecordingResult.t/0","type":"type"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordingResult.html#to_json/1","title":"Onvif.Search.Schemas.FindRecordingResult.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordingResult.html#to_struct/1","title":"Onvif.Search.Schemas.FindRecordingResult.to_struct/1","type":"function"},{"doc":"Module describing the FindRecordings schema.","ref":"Onvif.Search.Schemas.FindRecordings.html","title":"Onvif.Search.Schemas.FindRecordings","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordings.html#changeset/2","title":"Onvif.Search.Schemas.FindRecordings.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordings.html#t:t/0","title":"Onvif.Search.Schemas.FindRecordings.t/0","type":"type"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordings.html#to_json/1","title":"Onvif.Search.Schemas.FindRecordings.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordings.html#to_struct/1","title":"Onvif.Search.Schemas.FindRecordings.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.FindRecordings.html#to_xml/1","title":"Onvif.Search.Schemas.FindRecordings.to_xml/1","type":"function"},{"doc":"Module describing the request to `Onvif.Search.GetRecordingSearchResults`.","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html","title":"Onvif.Search.Schemas.GetRecordingSearchResults","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html#changeset/2","title":"Onvif.Search.Schemas.GetRecordingSearchResults.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html#t:t/0","title":"Onvif.Search.Schemas.GetRecordingSearchResults.t/0","type":"type"},{"doc":"","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html#to_json/1","title":"Onvif.Search.Schemas.GetRecordingSearchResults.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html#to_struct/1","title":"Onvif.Search.Schemas.GetRecordingSearchResults.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.GetRecordingSearchResults.html#to_xml/1","title":"Onvif.Search.Schemas.GetRecordingSearchResults.to_xml/1","type":"function"},{"doc":"A module describing recording information.","ref":"Onvif.Search.Schemas.RecordingInformation.html","title":"Onvif.Search.Schemas.RecordingInformation","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.html#changeset/2","title":"Onvif.Search.Schemas.RecordingInformation.changeset/2","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.html#parse/1","title":"Onvif.Search.Schemas.RecordingInformation.parse/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.html#t:t/0","title":"Onvif.Search.Schemas.RecordingInformation.t/0","type":"type"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.html#to_json/1","title":"Onvif.Search.Schemas.RecordingInformation.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.html#to_struct/1","title":"Onvif.Search.Schemas.RecordingInformation.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.RecordingSourceInformation.html","title":"Onvif.Search.Schemas.RecordingInformation.RecordingSourceInformation","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.RecordingInformation.TrackInformation.html","title":"Onvif.Search.Schemas.RecordingInformation.TrackInformation","type":"module"},{"doc":"A module representing a schema for search scope.","ref":"Onvif.Search.Schemas.SearchScope.html","title":"Onvif.Search.Schemas.SearchScope","type":"module"},{"doc":"","ref":"Onvif.Search.Schemas.SearchScope.html#t:t/0","title":"Onvif.Search.Schemas.SearchScope.t/0","type":"type"},{"doc":"","ref":"Onvif.Search.Schemas.SearchScope.html#to_json/1","title":"Onvif.Search.Schemas.SearchScope.to_json/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.SearchScope.html#to_struct/1","title":"Onvif.Search.Schemas.SearchScope.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.SearchScope.html#to_xml/1","title":"Onvif.Search.Schemas.SearchScope.to_xml/1","type":"function"},{"doc":"","ref":"Onvif.Search.Schemas.SearchScope.SourceReference.html","title":"Onvif.Search.Schemas.SearchScope.SourceReference","type":"module"},{"doc":"Interface for making requests to the Onvif PTZ(Pan/Tilt/Zoom) service\n\n  https://www.onvif.org/onvif/ver20/ptz/wsdl/ptz.wsdl","ref":"Onvif.PTZ.html","title":"Onvif.PTZ","type":"module"},{"doc":"","ref":"Onvif.PTZ.html#request/3","title":"Onvif.PTZ.request/3","type":"function"},{"doc":"Get the descriptions of the available PTZ Nodes.\n\nA PTZ-capable device may have multiple PTZ Nodes. The PTZ Nodes may represent mechanical PTZ drivers, uploaded PTZ drivers or digital PTZ drivers.\nPTZ Nodes are the lowest level entities in the PTZ control API and reflect the supported PTZ capabilities.\n\nThe PTZ Node is referenced either by its name or by its reference token.","ref":"Onvif.PTZ.GetNodes.html","title":"Onvif.PTZ.GetNodes","type":"module"},{"doc":"","ref":"Onvif.PTZ.GetNodes.html#request/1","title":"Onvif.PTZ.GetNodes.request/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.GetNodes.html#request_body/0","title":"Onvif.PTZ.GetNodes.request_body/0","type":"function"},{"doc":"","ref":"Onvif.PTZ.GetNodes.html#response/1","title":"Onvif.PTZ.GetNodes.response/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.GetNodes.html#soap_action/0","title":"Onvif.PTZ.GetNodes.soap_action/0","type":"function"},{"doc":"Module describing a PTZ node.","ref":"Onvif.PTZ.Schemas.PTZNode.html","title":"Onvif.PTZ.Schemas.PTZNode","type":"module"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.html#changeset/2","title":"Onvif.PTZ.Schemas.PTZNode.changeset/2","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.html#parse/1","title":"Onvif.PTZ.Schemas.PTZNode.parse/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.html#t:t/0","title":"Onvif.PTZ.Schemas.PTZNode.t/0","type":"type"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.html#to_json/1","title":"Onvif.PTZ.Schemas.PTZNode.to_json/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.html#to_struct/1","title":"Onvif.PTZ.Schemas.PTZNode.to_struct/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.Extension.html","title":"Onvif.PTZ.Schemas.PTZNode.Extension","type":"module"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.Extension.SupportedPresetTour.html","title":"Onvif.PTZ.Schemas.PTZNode.Extension.SupportedPresetTour","type":"module"},{"doc":"","ref":"Onvif.PTZ.Schemas.PTZNode.SupportedPTZSpaces.html","title":"Onvif.PTZ.Schemas.PTZNode.SupportedPTZSpaces","type":"module"},{"doc":"Module describing a 1D space.","ref":"Onvif.PTZ.Schemas.Space1DDescription.html","title":"Onvif.PTZ.Schemas.Space1DDescription","type":"module"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space1DDescription.html#changeset/2","title":"Onvif.PTZ.Schemas.Space1DDescription.changeset/2","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space1DDescription.html#parse/1","title":"Onvif.PTZ.Schemas.Space1DDescription.parse/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space1DDescription.html#t:t/0","title":"Onvif.PTZ.Schemas.Space1DDescription.t/0","type":"type"},{"doc":"Module describing a 2D space.","ref":"Onvif.PTZ.Schemas.Space2DDescription.html","title":"Onvif.PTZ.Schemas.Space2DDescription","type":"module"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space2DDescription.html#changeset/2","title":"Onvif.PTZ.Schemas.Space2DDescription.changeset/2","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space2DDescription.html#parse/1","title":"Onvif.PTZ.Schemas.Space2DDescription.parse/1","type":"function"},{"doc":"","ref":"Onvif.PTZ.Schemas.Space2DDescription.html#t:t/0","title":"Onvif.PTZ.Schemas.Space2DDescription.t/0","type":"type"},{"doc":"# Onvif\n\n[![Hex.pm](https://img.shields.io/hexpm/v/onvif.svg)](https://hex.pm/packages/onvif)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/onvif)\n\n**Elixir interface for Onvif functions**","ref":"readme.html","title":"Onvif","type":"extras"},{"doc":"The package can be installed by adding `onvif` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:onvif, \"~> 0.5.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Onvif","type":"extras"},{"doc":"This library provides an interface for an Elixir application to make requests to Onvif compliant devices.\nA request requires a `Device` struct which contains data necessary to successfully make the request, including\nan address, username, password, a best guess at which authentication method will work, and paths for several\nOnvif services, include Media and Device services. An Onvif compliant device should implement functions outlined\nin Onvif documentation, depending on which profiles with which the device claims to be compliant. That said,\na disclaimer that nothing is guaranteed and devices may not respond to requests for services that should be\nimplemented.\n\nTo start, make a probe request:\n```\n> Onvif.Discovery.probe()\n[\n  %Onvif.Discovery.Probe{\n    address: ...\n  }\n]\n```\n\nThis will return a list of devices on the network that respond to Web Services Dynamic Discovery. The request\n_should_ filter any non-video device but it is possibly that printers, etc. will show up and will need to be\nfiltered by application logic. If you already have information about the device, you can use:\n```\n> Onvif.Discovery.probe_by(ip_address: \"127.0.0.1\")\n%Onvif.Discovery.Probe{\n  address: [...],\n  device_ip: \"127.0.0.1\",\n  ...\n}\n```\nMore details in the `Onvif.Discovery.probe_by/1` docs.\n\nOnce you have a valid `Probe` struct, you can initialize a device.\n```\n> Onvif.Device.init(probe, username, password)\n%Onvif.Device{\n  ...\n}\n```","ref":"readme.html#how-to-use","title":"How to use - Onvif","type":"extras"}],"producer":{"name":"ex_doc","version":"0.36.1"},"proglang":"elixir"}